# fit_nbinom
Negative binomial maximum likelihood estimate implementation in Python using scipy and numpy. 
See http://en.wikipedia.org/wiki/Negative_binomial_distribution#Maximum_likelihood_estimation for used approach.
